@@ -14,6 +14,7 @@ struct directshow_property {
 	long int_from;
 	long int_to;
 	long flags;
+	bool move_enabled;
 };
 
 struct move_directshow_info {
@@ -29,6 +30,8 @@ struct move_directshow_info {
 	long int_to;
 	long int_value;
 	long int_from;
+	long int_min;
+	long int_max;
 
 	std::map<long, struct directshow_property> *camControlProps;
 	std::map<long, struct directshow_property> *procAmpProps;
@@ -156,27 +159,39 @@ void LoadProperties(move_directshow_info *move_directshow, obs_data_t *settings,
 				snprintf(number, 4, "%i", i);
 				std::string prop_id = "camera_control_";
 				prop_id += number;
+				std::string prop_enabled = prop_id;
+				prop_enabled += "_enabled";
 				if (m ==
 				    move_directshow->camControlProps->end()) {
 					struct directshow_property p;
 					p.int_from = val;
-					if (settings)
-						p.int_to = obs_data_get_int(
+					if (settings) {
+						p.int_to =
+							(long)obs_data_get_int(
+								settings,
+								prop_id.c_str());
+						p.move_enabled = obs_data_get_bool(
 							settings,
-							prop_id.c_str());
-					else
+							prop_enabled.c_str());
+					} else {
 						p.int_to = val;
-
+					}
 					move_directshow->camControlProps
 						->emplace(i, p);
 				} else {
 					if (overwrite)
 						m->second.int_from = val;
-					if (settings)
+					if (settings) {
 						m->second.int_to =
-							obs_data_get_int(
+							(long)obs_data_get_int(
 								settings,
 								prop_id.c_str());
+						m->second.move_enabled =
+							obs_data_get_bool(
+								settings,
+								prop_enabled
+									.c_str());
+					}
 				}
 			} else if (m !=
 				   move_directshow->camControlProps->end()) {
@@ -195,28 +210,40 @@ void LoadProperties(move_directshow_info *move_directshow, obs_data_t *settings,
 				snprintf(number, 4, "%i", i);
 				std::string prop_id = "video_proc_amp_";
 				prop_id += number;
-
+				std::string prop_enabled = prop_id;
+				prop_enabled += "_enabled";
 				if (m == move_directshow->procAmpProps->end()) {
 					struct directshow_property p;
 					p.int_from = val;
-					if (settings)
-						p.int_to = obs_data_get_int(
-							settings,
-							prop_id.c_str());
-					else
-						p.int_to = val;
-
-					move_directshow->procAmpProps
-						->emplace(i, p);
-
-				} else{
-					if (overwrite)
-						m->second.int_from = val;
-					if (settings)
-						m->second.int_to =
-							obs_data_get_int(
+					if (settings) {
+						p.int_to =
+							(long)obs_data_get_int(
 								settings,
 								prop_id.c_str());
+						p.move_enabled = obs_data_get_bool(
+							settings,
+							prop_enabled.c_str());
+					} else {
+						p.int_to = val;
+					}
+
+					move_directshow->procAmpProps->emplace(
+						i, p);
+
+				} else {
+					if (overwrite)
+						m->second.int_from = val;
+					if (settings) {
+						m->second.int_to =
+							(long)obs_data_get_int(
+								settings,
+								prop_id.c_str());
+						m->second.move_enabled =
+							obs_data_get_bool(
+								settings,
+								prop_enabled
+									.c_str());
+					}
 				}
 			} else if (m != move_directshow->procAmpProps->end()) {
 				move_directshow->procAmpProps->erase(m);
@@ -239,11 +266,16 @@ void move_directshow_update(void *data, obs_data_t *settings)
 		LoadDevice(move_directshow);
 	}
 	move_directshow->move_value_type =
-		obs_data_get_int(settings, S_MOVE_VALUE_TYPE);
-	if (move_directshow->move_value_type ==
-	    MOVE_VALUE_TYPE_SINGLE_SETTING) {
-		move_directshow->int_to =
-			obs_data_get_int(settings, S_SETTING_INT);
+		(int)obs_data_get_int(settings, S_MOVE_VALUE_TYPE);
+	if (move_directshow->move_value_type == MOVE_VALUE_TYPE_SETTINGS) {
+		LoadProperties(move_directshow, settings, false);
+	} else {
+		move_directshow->int_value =
+			(long)obs_data_get_int(settings, S_SETTING_INT);
+		move_directshow->int_min =
+			(long)obs_data_get_int(settings, S_SETTING_INT_MIN);
+		move_directshow->int_max =
+			(long)obs_data_get_int(settings, S_SETTING_INT_MAX);
 		auto single_setting_name =
 			obs_data_get_string(settings, S_SETTING_NAME);
 		if (!move_directshow->single_setting_name ||
@@ -253,8 +285,6 @@ void move_directshow_update(void *data, obs_data_t *settings)
 			move_directshow->single_setting_name =
 				bstrdup(single_setting_name);
 		}
-	} else {
-		LoadProperties(move_directshow, settings, false);
 	}
 }
 
@@ -264,6 +294,13 @@ static const char *move_directshow_get_name(void *type_data)
 	return obs_module_text("MoveDirectshowFilter");
 }
 
+long rand_between(long a, long b)
+{
+	if (a == b)
+		return a;
+	return b > a ? a + rand() % (b - a) : b + rand() % (a - b);
+}
+
 void move_directshow_start(void *data)
 {
 	struct move_directshow_info *move_directshow =
@@ -274,35 +311,82 @@ void move_directshow_start(void *data)
 	if (move_directshow->move_filter.reverse)
 		return;
 
-	if (move_directshow->move_value_type ==
-	    MOVE_VALUE_TYPE_SINGLE_SETTING) {
-		if (move_directshow->single_setting_name) {
-			long i;
-			pthread_mutex_lock(&move_directshow->mutex);
-			if (move_directshow->camControl &&
-			    1 == sscanf(move_directshow->single_setting_name,
-					"camera_control_%i", &i)) {
-				long val, flags;
-				HRESULT hr = move_directshow->camControl->Get(
-					i, &val, &flags);
-				if (hr == S_OK) {
-					move_directshow->int_from = val;
+	if (move_directshow->move_value_type == MOVE_VALUE_TYPE_SETTINGS) {
+		LoadProperties(move_directshow, nullptr, true);
+	} else if (move_directshow->single_setting_name) {
+		long i;
+		pthread_mutex_lock(&move_directshow->mutex);
+		if (move_directshow->camControl &&
+		    1 == sscanf(move_directshow->single_setting_name,
+				"camera_control_%i", &i)) {
+			long val, flags;
+			HRESULT hr = move_directshow->camControl->Get(i, &val,
+								      &flags);
+			if (hr == S_OK) {
+				move_directshow->int_from = val;
+				if (move_directshow->move_value_type ==
+				    MOVE_VALUE_TYPE_SETTING_ADD) {
+					move_directshow->int_to =
+						move_directshow->int_from +
+						move_directshow->int_value;
+					long min, max, delta, default_val, caps;
+					hr = move_directshow->camControl
+						     ->GetRange(i, &min, &max,
+								&delta,
+								&default_val,
+								&caps);
+					if (hr == S_OK) {
+						if (move_directshow->int_to <
+						    min)
+							move_directshow->int_to =
+								min;
+						if (move_directshow->int_to >
+						    max)
+							move_directshow->int_to =
+								max;
+					}
 				}
-			} else if (move_directshow->procAmp &&
-				   1 == sscanf(move_directshow
-						       ->single_setting_name,
-					       "video_proc_amp_%i", &i)) {
-				long val, flags;
-				HRESULT hr = move_directshow->procAmp->Get(
-					i, &val, &flags);
-				if (hr == S_OK) {
-					move_directshow->int_from = val;
+			}
+		} else if (move_directshow->procAmp &&
+			   1 == sscanf(move_directshow->single_setting_name,
+				       "video_proc_amp_%i", &i)) {
+			long val, flags;
+			HRESULT hr =
+				move_directshow->procAmp->Get(i, &val, &flags);
+			if (hr == S_OK) {
+				move_directshow->int_from = val;
+				if (move_directshow->move_value_type ==
+				    MOVE_VALUE_TYPE_SETTING_ADD) {
+					move_directshow->int_to =
+						move_directshow->int_from +
+						move_directshow->int_value;
+					long min, max, delta, default_val, caps;
+					hr = move_directshow->procAmp->GetRange(
+						i, &min, &max, &delta,
+						&default_val, &caps);
+					if (hr == S_OK) {
+						if (move_directshow->int_to <
+						    min)
+							move_directshow->int_to =
+								min;
+						if (move_directshow->int_to >
+						    max)
+							move_directshow->int_to =
+								max;
+					}
 				}
 			}
-			pthread_mutex_unlock(&move_directshow->mutex);
 		}
-	} else {
-		LoadProperties(move_directshow, nullptr, true);
+		pthread_mutex_unlock(&move_directshow->mutex);
+		if (move_directshow->move_value_type ==
+		    MOVE_VALUE_TYPE_RANDOM) {
+			move_directshow->int_to =
+				rand_between(move_directshow->int_min,
+					     move_directshow->int_max);
+		} else if (move_directshow->move_value_type !=
+			   MOVE_VALUE_TYPE_SETTING_ADD) {
+			move_directshow->int_to = move_directshow->int_value;
+		}
 	}
 }
 
@@ -366,15 +450,63 @@ static bool device_modified(void *priv, obs_properties_t *props,
 	}
 	auto single = obs_properties_get(props, S_SETTING_NAME);
 	auto single_int = obs_properties_get(props, S_SETTING_INT);
-	if (obs_data_get_int(settings, S_MOVE_VALUE_TYPE) ==
-	    MOVE_VALUE_TYPE_SINGLE_SETTING) {
+	auto prop_int_min = obs_properties_get(props, S_SETTING_INT_MIN);
+	auto prop_int_max = obs_properties_get(props, S_SETTING_INT_MAX);
+
+	auto move_type = (int)obs_data_get_int(settings, S_MOVE_VALUE_TYPE);
+	if (move_type != move_directshow->move_value_type) {
+		changed = true;
+		move_directshow->move_value_type = move_type;
+	}
+	if (move_type == MOVE_VALUE_TYPE_SETTINGS) {
+		if (obs_property_visible(single)) {
+			obs_property_set_visible(single, false);
+			changed = true;
+		}
+		single = nullptr;
+		if (obs_property_visible(single_int)) {
+			obs_property_set_visible(single_int, false);
+			changed = true;
+		}
+		if (obs_property_visible(prop_int_min)) {
+			obs_property_set_visible(prop_int_min, false);
+			changed = true;
+		}
+		if (obs_property_visible(prop_int_max)) {
+			obs_property_set_visible(prop_int_max, false);
+			changed = true;
+		}
+	} else {
 		if (!obs_property_visible(single)) {
 			obs_property_set_visible(single, true);
 			changed = true;
 		}
-		if (!obs_property_visible(single_int)) {
-			obs_property_set_visible(single_int, true);
-			changed = true;
+		if (move_type == MOVE_VALUE_TYPE_RANDOM) {
+			if (obs_property_visible(single_int)) {
+				obs_property_set_visible(single_int, false);
+				changed = true;
+			}
+			if (!obs_property_visible(prop_int_min)) {
+				obs_property_set_visible(prop_int_min, true);
+				changed = true;
+			}
+			if (!obs_property_visible(prop_int_max)) {
+				obs_property_set_visible(prop_int_max, true);
+				changed = true;
+			}
+		} else {
+			if (!obs_property_visible(single_int)) {
+				obs_property_set_visible(single_int, true);
+				changed = true;
+			}
+			if (obs_property_visible(prop_int_min)) {
+				obs_property_set_visible(prop_int_min, false);
+				changed = true;
+			}
+			if (obs_property_visible(prop_int_max)) {
+				obs_property_set_visible(prop_int_max, false);
+				changed = true;
+			}
 		}
 		auto p = obs_properties_get(props, "camcontrol_group");
 		if (p && obs_property_visible(p)) {
@@ -386,16 +518,6 @@ static bool device_modified(void *priv, obs_properties_t *props,
 			obs_property_set_visible(p, false);
 			changed = true;
 		}
-	} else {
-		if (obs_property_visible(single)) {
-			obs_property_set_visible(single, false);
-			changed = true;
-		}
-		single = nullptr;
-		if (obs_property_visible(single_int)) {
-			obs_property_set_visible(single_int, false);
-			changed = true;
-		}
 	}
 	if (!move_directshow->device ||
 	    strcmp(move_directshow->device, device) != 0) {
@@ -504,14 +626,42 @@ static bool device_modified(void *priv, obs_properties_t *props,
 						   prop_id.c_str()) == 0) {
 						auto p = obs_properties_get(
 							props, S_SETTING_INT);
+						if (move_type ==
+						    MOVE_VALUE_TYPE_SETTING_ADD) {
+							obs_property_int_set_limits(
+								p, -(max - min),
+								max - min,
+								delta);
+						} else {
+							obs_property_int_set_limits(
+								p, min, max,
+								delta);
+						}
+						p = obs_properties_get(
+							props,
+							S_SETTING_INT_MIN);
+						obs_property_int_set_limits(
+							p, min, max, delta);
+						p = obs_properties_get(
+							props,
+							S_SETTING_INT_MAX);
 						obs_property_int_set_limits(
 							p, min, max, delta);
 					}
 				} else {
+					std::string prop_enabled = prop_id;
+					prop_enabled += "_enabled";
+					obs_properties_t *prop_group =
+						obs_properties_create();
 					obs_properties_add_int_slider(
+						prop_group, prop_id.c_str(),
+						name.c_str(), min, max, delta);
+					obs_properties_add_group(
 						camcontrolGroup,
-						prop_id.c_str(), name.c_str(),
-						min, max, delta);
+						prop_enabled.c_str(),
+						name.c_str(),
+						OBS_GROUP_CHECKABLE,
+						prop_group);
 				}
 			}
 		}
@@ -565,13 +715,43 @@ static bool device_modified(void *priv, obs_properties_t *props,
 						   prop_id.c_str()) == 0) {
 						auto p = obs_properties_get(
 							props, S_SETTING_INT);
+						if (move_type ==
+						    MOVE_VALUE_TYPE_SETTING_ADD) {
+							obs_property_int_set_limits(
+								p, -(max - min),
+								max - min,
+								delta);
+						} else {
+							obs_property_int_set_limits(
+								p, min, max,
+								delta);
+						}
+						p = obs_properties_get(
+							props,
+							S_SETTING_INT_MIN);
+						obs_property_int_set_limits(
+							p, min, max, delta);
+						p = obs_properties_get(
+							props,
+							S_SETTING_INT_MAX);
 						obs_property_int_set_limits(
 							p, min, max, delta);
 					}
 				} else {
+					std::string prop_enabled = prop_id;
+					prop_enabled += "_enabled";
+					obs_properties_t *prop_group =
+						obs_properties_create();
 					obs_properties_add_int_slider(
-						procAmpGroup, prop_id.c_str(),
+						prop_group, prop_id.c_str(),
 						name.c_str(), min, max, delta);
+
+					obs_properties_add_group(
+						procAmpGroup,
+						prop_enabled.c_str(),
+						name.c_str(),
+						OBS_GROUP_CHECKABLE,
+						prop_group);
 				}
 			}
 		}
@@ -596,8 +776,6 @@ static bool device_modified(void *priv, obs_properties_t *props,
 	return true;
 }
 
-
-
 bool move_directshow_get_value(obs_properties_t *props,
 			       obs_property_t *property, void *data)
 {
@@ -622,6 +800,28 @@ bool move_directshow_get_value(obs_properties_t *props,
 					   prop_id.c_str()) == 0) {
 					obs_data_set_int(settings,
 							 S_SETTING_INT, val);
+					if (move_directshow->move_value_type ==
+					    MOVE_VALUE_TYPE_RANDOM) {
+						long min, max, delta,
+							default_val, caps;
+						hr = move_directshow->camControl
+							     ->GetRange(
+								     i, &min,
+								     &max,
+								     &delta,
+								     &default_val,
+								     &caps);
+						if (hr == S_OK) {
+							obs_data_set_int(
+								settings,
+								S_SETTING_INT_MIN,
+								min);
+							obs_data_set_int(
+								settings,
+								S_SETTING_INT_MAX,
+								max);
+						}
+					}
 				}
 				obs_data_set_int(settings, prop_id.c_str(),
 						 val);
@@ -643,6 +843,28 @@ bool move_directshow_get_value(obs_properties_t *props,
 					   prop_id.c_str()) == 0) {
 					obs_data_set_int(settings,
 							 S_SETTING_INT, val);
+					if (move_directshow->move_value_type ==
+					    MOVE_VALUE_TYPE_RANDOM) {
+						long min, max, delta,
+							default_val, caps;
+						hr = move_directshow->procAmp
+							     ->GetRange(
+								     i, &min,
+								     &max,
+								     &delta,
+								     &default_val,
+								     &caps);
+						if (hr == S_OK) {
+							obs_data_set_int(
+								settings,
+								S_SETTING_INT_MIN,
+								min);
+							obs_data_set_int(
+								settings,
+								S_SETTING_INT_MAX,
+								max);
+						}
+					}
 				}
 				obs_data_set_int(settings, prop_id.c_str(),
 						 val);
@@ -650,7 +872,7 @@ bool move_directshow_get_value(obs_properties_t *props,
 		}
 	}
 	pthread_mutex_unlock(&move_directshow->mutex);
-
+	move_directshow_update(data, settings);
 	obs_data_release(settings);
 	return true;
 }
@@ -734,6 +956,11 @@ static obs_properties_t *move_directshow_properties(void *data)
 		MOVE_VALUE_TYPE_SINGLE_SETTING);
 	obs_property_list_add_int(p, obs_module_text("MoveValueType.Settings"),
 				  MOVE_VALUE_TYPE_SETTINGS);
+	obs_property_list_add_int(p, obs_module_text("MoveValueType.Random"),
+				  MOVE_VALUE_TYPE_RANDOM);
+	obs_property_list_add_int(p,
+				  obs_module_text("MoveValueType.SettingAdd"),
+				  MOVE_VALUE_TYPE_SETTING_ADD);
 
 	obs_property_set_modified_callback2(p, device_modified, data);
 
@@ -744,8 +971,15 @@ static obs_properties_t *move_directshow_properties(void *data)
 
 	obs_property_set_modified_callback2(p, device_modified, data);
 
-	obs_properties_add_int_slider(ppts, S_SETTING_INT,
-				      obs_module_text("Value"), 0, 0, 1);
+	p = obs_properties_add_int_slider(ppts, S_SETTING_INT,
+					  obs_module_text("Value"), 0, 0, 1);
+	obs_property_set_visible(p, false);
+	p = obs_properties_add_int_slider(ppts, S_SETTING_INT_MIN,
+					  obs_module_text("MinValue"), 0, 0, 1);
+	obs_property_set_visible(p, false);
+	p = obs_properties_add_int_slider(ppts, S_SETTING_INT_MAX,
+					  obs_module_text("MaxValue"), 0, 0, 1);
+	obs_property_set_visible(p, false);
 
 	obs_properties_add_group(ppts, "camcontrol_group",
 				 obs_module_text("CameraControl"),
@@ -796,48 +1030,19 @@ void move_directshow_tick(void *data, float seconds)
 		return;
 
 	pthread_mutex_lock(&move_directshow->mutex);
-	if (move_directshow->move_value_type ==
-	    MOVE_VALUE_TYPE_SINGLE_SETTING) {
-		if (move_directshow->single_setting_name) {
-			const long value_int =
-				(long long)((1.0 - t) * (double)move_directshow
-								->int_from +
-					    t * (double)move_directshow->int_to);
-			long i;
-			if (move_directshow->camControl &&
-			    1 == sscanf(move_directshow->single_setting_name,
-					"camera_control_%i", &i)) {
-				long val, flags;
-				HRESULT hr = move_directshow->camControl->Get(
-					i, &val, &flags);
-				if (hr == S_OK && val != value_int) {
-					move_directshow->camControl->Set(
-						i, value_int, flags);
-				}
-			} else if (move_directshow->procAmp &&
-				   1 == sscanf(move_directshow
-						       ->single_setting_name,
-					       "video_proc_amp_%i", &i)) {
-				long val, flags;
-				HRESULT hr = move_directshow->procAmp->Get(
-					i, &val, &flags);
-				if (hr == S_OK && val != value_int) {
-					move_directshow->procAmp->Set(
-						i, value_int, flags);
-				}
-			}
-		}
-	} else {
+	if (move_directshow->move_value_type == MOVE_VALUE_TYPE_SETTINGS) {
 		if (move_directshow->camControl) {
 			for (auto prop =
 				     move_directshow->camControlProps->begin();
 			     prop != move_directshow->camControlProps->end();
 			     ++prop) {
+				if (!prop->second.move_enabled)
+					continue;
 				const long value_int =
-					(long long)((1.0 -
-						     t) * (double)(prop->second
-									   .int_from) +
-						    t * (double)prop->second
+					(long long)((1.0f -
+						     t) * (float)(prop->second
+									  .int_from) +
+						    t * (float)prop->second
 								    .int_to);
 				long val, flags;
 				HRESULT hr = move_directshow->camControl->Get(
@@ -852,11 +1057,13 @@ void move_directshow_tick(void *data, float seconds)
 			for (auto prop = move_directshow->procAmpProps->begin();
 			     prop != move_directshow->procAmpProps->end();
 			     ++prop) {
+				if (!prop->second.move_enabled)
+					continue;
 				const long value_int =
-					(long long)((1.0 -
-						     t) * (double)(prop->second
-									   .int_from) +
-						    t * (double)prop->second
+					(long long)((1.0f -
+						     t) * (float)(prop->second
+									  .int_from) +
+						    t * (float)prop->second
 								    .int_to);
 				long val, flags;
 				HRESULT hr = move_directshow->procAmp->Get(
@@ -867,6 +1074,33 @@ void move_directshow_tick(void *data, float seconds)
 				}
 			}
 		}
+	} else if (move_directshow->single_setting_name) {
+		const long value_int =
+			(long long)((1.0f - t) *
+					    (float)move_directshow->int_from +
+				    t * (float)move_directshow->int_to);
+		long i;
+		if (move_directshow->camControl &&
+		    1 == sscanf(move_directshow->single_setting_name,
+				"camera_control_%i", &i)) {
+			long val, flags;
+			HRESULT hr = move_directshow->camControl->Get(i, &val,
+								      &flags);
+			if (hr == S_OK && val != value_int) {
+				move_directshow->camControl->Set(i, value_int,
+								 flags);
+			}
+		} else if (move_directshow->procAmp &&
+			   1 == sscanf(move_directshow->single_setting_name,
+				       "video_proc_amp_%i", &i)) {
+			long val, flags;
+			HRESULT hr =
+				move_directshow->procAmp->Get(i, &val, &flags);
+			if (hr == S_OK && val != value_int) {
+				move_directshow->procAmp->Set(i, value_int,
+							      flags);
+			}
+		}
 	}
 	pthread_mutex_unlock(&move_directshow->mutex);
 
@@ -877,6 +1111,7 @@ void move_directshow_tick(void *data, float seconds)
 void move_directshow_defaults(obs_data_t *settings)
 {
 	obs_data_set_default_bool(settings, S_ENABLED_MATCH_MOVING, true);
+	obs_data_set_default_int(settings, S_DURATION, 300);
 }
 
 extern "C" {
