@@ -3,6 +3,8 @@
 
 bool is_move_filter(const char *filter_id)
 {
+	if (!filter_id)
+		return false;
 	return strcmp(filter_id, MOVE_SOURCE_FILTER_ID) == 0 ||
 	       strcmp(filter_id, MOVE_VALUE_FILTER_ID) == 0 ||
 	       strcmp(filter_id, MOVE_AUDIO_VALUE_FILTER_ID) == 0 ||
@@ -125,6 +127,13 @@ void move_filter_start_hotkey(struct move_filter *move_filter)
 		}
 		if (next_move_on != NEXT_MOVE_ON_HOTKEY) {
 			da_push_back(move_filter->filters_done, &filter);
+		} else if (strcmp(next_move_name, NEXT_MOVE_REVERSE) == 0 &&
+			   !obs_source_removed(filter) &&
+			   is_move_filter(
+				   obs_source_get_unversioned_id(filter))) {
+			move_filter_start(obs_obj_get_data(filter));
+			move_filter->filters_done.num = 0;
+			return;
 		}
 		filter = obs_source_get_filter_by_name(parent, next_move_name);
 		if (!filter && move_filter->get_alternative_source) {
@@ -137,7 +146,8 @@ void move_filter_start_hotkey(struct move_filter *move_filter)
 		}
 
 		if (filter) {
-			if (is_move_filter(
+			if (!obs_source_removed(filter) &&
+			    is_move_filter(
 				    obs_source_get_unversioned_id(filter))) {
 				struct move_filter *filter_data =
 					obs_obj_get_data(filter);
@@ -178,7 +188,8 @@ void move_filter_start_hotkey(struct move_filter *move_filter)
 			return;
 		}
 	}
-	if (is_move_filter(obs_source_get_unversioned_id(filter))) {
+	if (!obs_source_removed(filter) &&
+	    is_move_filter(obs_source_get_unversioned_id(filter))) {
 		move_filter_start(obs_obj_get_data(filter));
 	}
 	da_push_back(move_filter->filters_done, &filter);
@@ -234,7 +245,8 @@ bool move_filter_start_internal(struct move_filter *move_filter)
 			}
 
 			if (filter) {
-				if (is_move_filter(
+				if (!obs_source_removed(filter) &&
+				    is_move_filter(
 					    obs_source_get_unversioned_id(
 						    filter))) {
 					move_filter_start(
@@ -301,7 +313,8 @@ extern void move_filter_ended(struct move_filter *move_filter)
 				}
 
 				if (filter) {
-					if (is_move_filter(
+					if (!obs_source_removed(filter) &&
+					    is_move_filter(
 						    obs_source_get_unversioned_id(
 							    filter))) {
 						move_filter_start(
@@ -349,11 +362,6 @@ bool move_filter_tick(struct move_filter *move_filter, float seconds, float *tp)
 	if (!move_filter->moving || !enabled)
 		return false;
 
-	if (!move_filter->duration) {
-		move_filter->moving = false;
-		return false;
-	}
-
 	move_filter->running_duration += seconds;
 	if (move_filter->running_duration * 1000.0f <
 	    (move_filter->reverse ? move_filter->end_delay
@@ -365,6 +373,10 @@ bool move_filter_tick(struct move_filter *move_filter, float seconds, float *tp)
 		    move_filter->end_delay)) {
 		move_filter->moving = false;
 	}
+	if (!move_filter->duration) {
+		*tp = 1.0f;
+		return true;
+	}
 	float t = (move_filter->running_duration * 1000.0f -
 		   (float)(move_filter->reverse ? move_filter->end_delay
 						: move_filter->start_delay)) /
@@ -411,7 +423,7 @@ void move_filter_properties(struct move_filter *move_filter,
 
 	obs_properties_t *duration = obs_properties_create();
 
-	p = obs_properties_add_int(duration, S_DURATION, "", 10, 10000000, 100);
+	p = obs_properties_add_int(duration, S_DURATION, "", 0, 10000000, 100);
 	obs_property_int_set_suffix(p, "ms");
 
 	p = obs_properties_add_group(ppts, S_CUSTOM_DURATION,
@@ -504,6 +516,8 @@ void move_filter_properties(struct move_filter *move_filter,
 	obs_properties_add_button(ppts, "move_filter_start",
 				  obs_module_text("Start"),
 				  move_filter_start_button);
+	obs_properties_add_text(ppts, "plugin_info", PLUGIN_INFO,
+				OBS_TEXT_INFO);
 }
 
 void move_filter_activate(void *data)
