@@ -159,19 +159,22 @@ void calc_relative_to(struct move_source_info *move_source)
 	obs_data_release(bounds);
 
 	obs_data_t *crop = obs_data_get_obj(settings, S_CROP);
-	move_source->crop_to.left = calc_sign(
-		obs_data_get_char(crop, "left_sign"),
-		move_source->crop_from.left, obs_data_get_int(crop, "left"));
-	move_source->crop_to.top = calc_sign(
-		obs_data_get_char(crop, "top_sign"), move_source->crop_from.top,
-		obs_data_get_int(crop, "top"));
-	move_source->crop_to.right = calc_sign(
-		obs_data_get_char(crop, "right_sign"),
-		move_source->crop_from.right, obs_data_get_int(crop, "right"));
+	move_source->crop_to.left =
+		(int)calc_sign(obs_data_get_char(crop, "left_sign"),
+			       (float)move_source->crop_from.left,
+			       (float)obs_data_get_int(crop, "left"));
+	move_source->crop_to.top =
+		(int)calc_sign(obs_data_get_char(crop, "top_sign"),
+			       (float)move_source->crop_from.top,
+			       (float)obs_data_get_int(crop, "top"));
+	move_source->crop_to.right =
+		(int)calc_sign(obs_data_get_char(crop, "right_sign"),
+			       (float)move_source->crop_from.right,
+			       (float)obs_data_get_int(crop, "right"));
 	move_source->crop_to.bottom =
-		calc_sign(obs_data_get_char(crop, "bottom_sign"),
-			  move_source->crop_from.bottom,
-			  obs_data_get_int(crop, "bottom"));
+		(int)calc_sign(obs_data_get_char(crop, "bottom_sign"),
+			       (float)move_source->crop_from.bottom,
+			       (float)obs_data_get_int(crop, "bottom"));
 	obs_data_release(crop);
 	obs_data_release(settings);
 }
@@ -317,7 +320,7 @@ void move_source_start(struct move_source_info *move_source)
 			    CHANGE_ORDER_ABSOLUTE) != 0) {
 			obs_sceneitem_set_order_position(
 				move_source->scene_item,
-				move_source->order_position);
+				(int)move_source->order_position);
 		}
 	}
 	if ((move_source->change_visibility == CHANGE_VISIBILITY_SHOW_START ||
@@ -798,7 +801,8 @@ static void *move_source_create(obs_data_t *settings, obs_source_t *source)
 {
 	struct move_source_info *move_source =
 		bzalloc(sizeof(struct move_source_info));
-	move_filter_init(&move_source->move_filter, source, move_source_start);
+	move_filter_init(&move_source->move_filter, source,
+			 (void (*)(void *))move_source_start);
 	move_source->move_filter.get_alternative_source =
 		move_source_get_source;
 	move_source_update(move_source, settings);
@@ -976,12 +980,7 @@ void prop_list_add_move_source_filter(obs_source_t *parent, obs_source_t *child,
 				      void *data)
 {
 	UNUSED_PARAMETER(parent);
-	if (strcmp(obs_source_get_unversioned_id(child),
-		   MOVE_SOURCE_FILTER_ID) != 0 &&
-	    strcmp(obs_source_get_unversioned_id(child),
-		   MOVE_VALUE_FILTER_ID) != 0 &&
-	    strcmp(obs_source_get_unversioned_id(child),
-		   MOVE_AUDIO_VALUE_FILTER_ID) != 0)
+	if (!is_move_filter(obs_source_get_unversioned_id(child)))
 		return;
 	obs_property_t *p = data;
 	const char *name = obs_source_get_name(child);
@@ -1165,9 +1164,12 @@ static obs_properties_t *move_source_properties(void *data)
 	if (!scene)
 		scene = obs_group_from_source(parent);
 	if (!scene) {
-		obs_properties_add_button(ppts, "warning",
-					  obs_module_text("ScenesOnlyFilter"),
-					  NULL);
+		obs_property_t *w = obs_properties_add_text(
+			ppts, "warning", obs_module_text("ScenesOnlyFilter"),
+			OBS_TEXT_INFO);
+		obs_property_text_set_info_type(w, OBS_TEXT_INFO_WARNING);
+		obs_properties_add_text(ppts, "plugin_info", PLUGIN_INFO,
+					OBS_TEXT_INFO);
 		return ppts;
 	}
 	if (!move_source->scene_item && move_source->source_name &&
@@ -1187,7 +1189,7 @@ static obs_properties_t *move_source_properties(void *data)
 				   100);
 	obs_property_int_set_suffix(p, "ms");
 	obs_properties_t *duration = obs_properties_create();
-	p = obs_properties_add_int(duration, S_DURATION, "", 10, 10000000, 100);
+	p = obs_properties_add_int(duration, S_DURATION, "", 0, 10000000, 100);
 	obs_property_int_set_suffix(p, "ms");
 	p = obs_properties_add_group(group, S_CUSTOM_DURATION,
 				     obs_module_text("CustomDuration"),
@@ -1467,6 +1469,8 @@ static obs_properties_t *move_source_properties(void *data)
 	p = obs_properties_add_group(ppts, S_ACTIONS,
 				     obs_module_text("Actions"),
 				     OBS_GROUP_NORMAL, group);
+	obs_properties_add_text(ppts, "plugin_info", PLUGIN_INFO,
+				OBS_TEXT_INFO);
 	return ppts;
 }
 
@@ -1559,7 +1563,7 @@ void move_source_ended(struct move_source_info *move_source)
 			    CHANGE_ORDER_ABSOLUTE) != 0) {
 			obs_sceneitem_set_order_position(
 				move_source->scene_item,
-				move_source->order_position);
+				(int)move_source->order_position);
 		}
 	}
 }
