@@ -4,7 +4,6 @@
 #include "graphics/math-defs.h"
 #include "graphics/matrix4.h"
 #include "easing.h"
-#include "version.h"
 
 struct move_info {
 	obs_source_t *source;
@@ -40,6 +39,7 @@ struct move_info {
 	bool matched_scene_a;
 	bool matched_scene_b;
 	uint32_t item_order_switch_percentage;
+	bool nested_scenes;
 	bool cache_transitions;
 	DARRAY(obs_source_t *) transition_pool_move;
 	size_t transition_pool_move_index;
@@ -68,6 +68,11 @@ struct move_item {
 	obs_scene_t *release_scene_b;
 };
 
+struct match_item3 {
+	obs_source_t *check_source;
+	bool matched;
+};
+
 static const struct {
 	enum gs_blend_type src_color;
 	enum gs_blend_type src_alpha;
@@ -285,6 +290,7 @@ static void move_update(void *data, obs_data_t *settings)
 		(uint32_t)obs_data_get_int(settings, S_SWITCH_PERCENTAGE);
 	move->cache_transitions =
 		obs_data_get_bool(settings, S_CACHE_TRANSITIONS);
+	move->nested_scenes = obs_data_get_bool(settings, S_NESTED_SCENES);
 }
 
 void add_alignment(struct vec2 *v, uint32_t align, int32_t cx, int32_t cy)
@@ -803,6 +809,16 @@ obs_source_t *get_transition(const char *transition_name, void *pool_data,
 	return transition;
 }
 
+float rot_diff(float rot_a, float rot_b)
+{
+	float diff = rot_b - rot_a;
+	while (diff < -180.0f)
+		diff += 360.0f;
+	while (diff > 180.0f)
+		diff -= 360.0f;
+	return diff;
+}
+
 bool render2_item(struct move_info *move, struct move_item *item)
 {
 	obs_sceneitem_t *scene_item = NULL;
@@ -821,40 +837,21 @@ bool render2_item(struct move_info *move, struct move_item *item)
 	uint32_t width = obs_source_get_width(source);
 	uint32_t height = obs_source_get_height(source);
 	bool move_out = item->item_a == scene_item;
-	if (item->move_scene) {
-		if (item->transition_name && !item->transition) {
-			item->transition = get_transition(
-				item->transition_name,
-				&move->transition_pool_move,
-				&move->transition_pool_move_index,
-				move->cache_transitions);
-			if (item->transition) {
-				obs_transition_set_size(item->transition, width,
-							height);
-				obs_transition_set_alignment(item->transition,
-							     OBS_ALIGN_CENTER);
-				obs_transition_set_scale_type(
-					item->transition,
-					item->transition_scale);
-				obs_transition_set(
-					item->transition,
-					obs_sceneitem_get_source(scene_item));
-				obs_transition_start(
-					item->transition,
-					obs_transition_fixed(item->transition)
-						? OBS_TRANSITION_MODE_AUTO
-						: OBS_TRANSITION_MODE_MANUAL,
-					obs_frontend_get_transition_duration(),
-					obs_sceneitem_get_source(scene_item));
+	if (item->item_a && item->item_b) {
+		if (!item->transition) {
+			if (item->move_scene) {
+				item->transition = get_transition(
+					obs_source_get_name(move->source),
+					&move->transition_pool_move,
+					&move->transition_pool_move_index,
+					move->cache_transitions);
+			} else {
+				item->transition = get_transition(
+					item->transition_name,
+					&move->transition_pool_move,
+					&move->transition_pool_move_index,
+					move->cache_transitions);
 			}
-		}
-	} else if (item->item_a && item->item_b) {
-		if (item->transition_name && !item->transition) {
-			item->transition = get_transition(
-				item->transition_name,
-				&move->transition_pool_move,
-				&move->transition_pool_move_index,
-				move->cache_transitions);
 			if (item->transition) {
 				obs_transition_set_size(item->transition, width,
 							height);
@@ -875,6 +872,33 @@ bool render2_item(struct move_info *move, struct move_item *item)
 					obs_sceneitem_get_source(item->item_b));
 			}
 		}
+	} else if (item->move_scene) {
+		if (item->transition_name && !item->transition) {
+			item->transition = get_transition(
+				item->transition_name,
+				&move->transition_pool_move,
+				&move->transition_pool_move_index,
+				move->cache_transitions);
+			if (item->transition) {
+				obs_transition_set_size(item->transition, width,
+							height);
+				obs_transition_set_alignment(item->transition,
+							     OBS_ALIGN_CENTER);
+				obs_transition_set_scale_type(
+					item->transition,
+					item->transition_scale);
+				obs_transition_set(
+					item->transition,
+					obs_sceneitem_get_source(scene_item));
+				obs_transition_start(
+					item->transition,
+					obs_transition_fixed(item->transition)
+						? OBS_TRANSITION_MODE_AUTO
+						: OBS_TRANSITION_MODE_MANUAL,
+					obs_frontend_get_transition_duration(),
+					obs_sceneitem_get_source(scene_item));
+			}
+		}
 	} else if (move_out && item->transition_name && !item->transition) {
 		item->transition = get_transition(
 			item->transition_name, &move->transition_pool_out,
@@ -972,7 +996,23 @@ bool render2_item(struct move_info *move, struct move_item *item)
 	uint32_t original_width = width;
 	uint32_t original_height = height;
 	struct obs_sceneitem_crop crop;
-	if (item->move_scene) {
+	if (item->item_a && item->item_b) {
+		struct obs_sceneitem_crop crop_a;
+		obs_sceneitem_get_crop(item->item_a, &crop_a);
+		struct obs_sceneitem_crop crop_b;
+		obs_sceneitem_get_crop(item->item_b, &crop_b);
+		crop.left =
+			(int)roundf((float)(1.0f - ot) * (float)crop_a.left +
+				    ot * (float)crop_b.left);
+		crop.top = (int)roundf((float)(1.0f - ot) * (float)crop_a.top +
+				       ot * (float)crop_b.top);
+		crop.right =
+			(int)roundf((float)(1.0f - ot) * (float)crop_a.right +
+				    ot * (float)crop_b.right);
+		crop.bottom =
+			(int)roundf((float)(1.0f - ot) * (float)crop_a.bottom +
+				    ot * (float)crop_b.bottom);
+	} else if (item->move_scene) {
 		obs_sceneitem_get_crop(scene_item, &crop);
 		if (item->item_a) {
 			crop.left = (int)roundf((float)(1.0f - ot) *
@@ -990,22 +1030,6 @@ bool render2_item(struct move_info *move, struct move_item *item)
 			crop.bottom =
 				(int)roundf((float)ot * (float)crop.bottom);
 		}
-	} else if (item->item_a && item->item_b) {
-		struct obs_sceneitem_crop crop_a;
-		obs_sceneitem_get_crop(item->item_a, &crop_a);
-		struct obs_sceneitem_crop crop_b;
-		obs_sceneitem_get_crop(item->item_b, &crop_b);
-		crop.left =
-			(int)roundf((float)(1.0f - ot) * (float)crop_a.left +
-				    ot * (float)crop_b.left);
-		crop.top = (int)roundf((float)(1.0f - ot) * (float)crop_a.top +
-				       ot * (float)crop_b.top);
-		crop.right =
-			(int)roundf((float)(1.0f - ot) * (float)crop_a.right +
-				    ot * (float)crop_b.right);
-		crop.bottom =
-			(int)roundf((float)(1.0f - ot) * (float)crop_a.bottom +
-				    ot * (float)crop_b.bottom);
 	} else {
 		obs_sceneitem_get_crop(scene_item, &crop);
 	}
@@ -1064,7 +1088,15 @@ bool render2_item(struct move_info *move, struct move_item *item)
 
 	if (obs_sceneitem_get_bounds_type(scene_item) != OBS_BOUNDS_NONE) {
 		struct vec2 bounds;
-		if (item->move_scene) {
+		if (item->item_a && item->item_b) {
+			struct vec2 bounds_a;
+			obs_sceneitem_get_bounds(item->item_a, &bounds_a);
+			struct vec2 bounds_b;
+			obs_sceneitem_get_bounds(item->item_b, &bounds_b);
+			vec2_set(&bounds,
+				 (1.0f - t) * bounds_a.x + t * bounds_b.x,
+				 (1.0f - t) * bounds_a.y + t * bounds_b.y);
+		} else if (item->move_scene) {
 			obs_sceneitem_get_bounds(scene_item, &bounds);
 			if (item->item_a) {
 				vec2_set(&bounds,
@@ -1079,14 +1111,6 @@ bool render2_item(struct move_info *move, struct move_item *item)
 					 (1.0f - t) * canvas_height +
 						 t * bounds.y);
 			}
-		} else if (item->item_a && item->item_b) {
-			struct vec2 bounds_a;
-			obs_sceneitem_get_bounds(item->item_a, &bounds_a);
-			struct vec2 bounds_b;
-			obs_sceneitem_get_bounds(item->item_b, &bounds_b);
-			vec2_set(&bounds,
-				 (1.0f - t) * bounds_a.x + t * bounds_b.x,
-				 (1.0f - t) * bounds_a.y + t * bounds_b.y);
 		} else {
 			obs_sceneitem_get_bounds(scene_item, &bounds);
 			if (!move_out && item->zoom) {
@@ -1139,17 +1163,20 @@ bool render2_item(struct move_info *move, struct move_item *item)
 	matrix4_translate3f(&draw_transform, &draw_transform, -origin.x,
 			    -origin.y, 0.0f);
 	float rot;
-	if (item->move_scene) {
-		rot = obs_sceneitem_get_rot(scene_item);
+	float rd = 0.0f;
+	if (item->item_a && item->item_b) {
+		float rot_a = obs_sceneitem_get_rot(item->item_a);
+		float rot_b = obs_sceneitem_get_rot(item->item_b);
+		rd = rot_diff(rot_a, rot_b);
+		rot = rot_a + t * rd;
+	} else if (item->move_scene) {
+		rd = rot_diff(0.0f, obs_sceneitem_get_rot(scene_item));
+		rot = rd;
 		if (item->item_a) {
 			rot *= (1.0f - t);
 		} else if (item->item_b) {
 			rot *= t;
 		}
-	} else if (item->item_a && item->item_b) {
-		float rot_a = obs_sceneitem_get_rot(item->item_a);
-		float rot_b = obs_sceneitem_get_rot(item->item_b);
-		rot = (1.0f - t) * rot_a + t * rot_b;
 	} else {
 		rot = obs_sceneitem_get_rot(scene_item);
 	}
@@ -1273,8 +1300,8 @@ bool render2_item(struct move_info *move, struct move_item *item)
 		gs_texrender_destroy(item->item_render);
 		item->item_render = NULL;
 	} else if (!item->item_render &&
-		   (item->item_a && item_texture_enabled(item->item_a) ||
-		    item->item_b && item_texture_enabled(item->item_b))) {
+		   ((item->item_a && item_texture_enabled(item->item_a)) ||
+		    (item->item_b && item_texture_enabled(item->item_b)))) {
 		item->item_render = gs_texrender_create(GS_RGBA, GS_ZS_NONE);
 	} else if (item->item_render) {
 		gs_texrender_reset(item->item_render);
@@ -1318,6 +1345,64 @@ bool render2_item(struct move_info *move, struct move_item *item)
 			gs_texrender_end(item->item_render);
 		}
 	}
+	if (item->item_a && item->item_b &&
+	    (fabs((double)rd) <= 90.0 ||
+	     (obs_sceneitem_get_bounds_type(item->item_a) == OBS_BOUNDS_NONE &&
+	      obs_sceneitem_get_bounds_type(item->item_b) != OBS_BOUNDS_NONE) ||
+	     (obs_sceneitem_get_bounds_type(item->item_a) != OBS_BOUNDS_NONE &&
+	      obs_sceneitem_get_bounds_type(item->item_b) == OBS_BOUNDS_NONE))) {
+		struct matrix4 transform_a;
+		obs_sceneitem_get_draw_transform(item->item_a, &transform_a);
+		if (isnan(transform_a.x.x) || isinf(transform_a.x.x)) {
+			obs_sceneitem_set_rot(
+				item->item_a,
+				obs_sceneitem_get_rot(item->item_a));
+			obs_sceneitem_get_draw_transform(item->item_a,
+							 &transform_a);
+		}
+		struct matrix4 transform_b;
+		obs_sceneitem_get_draw_transform(item->item_b, &transform_b);
+		if (isnan(transform_b.x.x) || isinf(transform_b.x.x)) {
+			obs_sceneitem_set_rot(
+				item->item_b,
+				obs_sceneitem_get_rot(item->item_b));
+			obs_sceneitem_get_draw_transform(item->item_b,
+							 &transform_b);
+		}
+
+		draw_transform.x.x =
+			(1.0f - t) * transform_a.x.x + t * transform_b.x.x;
+		draw_transform.x.y =
+			(1.0f - t) * transform_a.x.y + t * transform_b.x.y;
+		draw_transform.x.z =
+			(1.0f - t) * transform_a.x.z + t * transform_b.x.z;
+		draw_transform.x.w =
+			(1.0f - t) * transform_a.x.w + t * transform_b.x.w;
+		draw_transform.y.x =
+			(1.0f - t) * transform_a.y.x + t * transform_b.y.x;
+		draw_transform.y.y =
+			(1.0f - t) * transform_a.y.y + t * transform_b.y.y;
+		draw_transform.y.z =
+			(1.0f - t) * transform_a.y.z + t * transform_b.y.z;
+		draw_transform.y.w =
+			(1.0f - t) * transform_a.y.w + t * transform_b.y.w;
+		draw_transform.z.x =
+			(1.0f - t) * transform_a.z.x + t * transform_b.z.x;
+		draw_transform.z.y =
+			(1.0f - t) * transform_a.z.y + t * transform_b.z.y;
+		draw_transform.z.z =
+			(1.0f - t) * transform_a.z.z + t * transform_b.z.z;
+		draw_transform.z.w =
+			(1.0f - t) * transform_a.z.w + t * transform_b.z.w;
+		draw_transform.t.x =
+			(1.0f - t) * transform_a.t.x + t * transform_b.t.x;
+		draw_transform.t.y =
+			(1.0f - t) * transform_a.t.y + t * transform_b.t.y;
+		draw_transform.t.z =
+			(1.0f - t) * transform_a.t.z + t * transform_b.t.z;
+		draw_transform.t.w =
+			(1.0f - t) * transform_a.t.w + t * transform_b.t.w;
+	}
 
 	gs_matrix_push();
 	gs_matrix_mul(&draw_transform);
@@ -1373,9 +1458,9 @@ bool render2_item(struct move_info *move, struct move_item *item)
 				scale_param = gs_effect_get_param_by_name(
 					effect, "base_dimension");
 				if (scale_param) {
-					struct vec2 base_res = {(float)cx,
-								(float)cy};
-
+					struct vec2 base_res;
+					base_res.x = (float)cx;
+					base_res.y = (float)cy;
 					gs_effect_set_vec2(scale_param,
 							   &base_res);
 				}
@@ -1383,9 +1468,9 @@ bool render2_item(struct move_info *move, struct move_item *item)
 				scale_i_param = gs_effect_get_param_by_name(
 					effect, "base_dimension_i");
 				if (scale_i_param) {
-					struct vec2 base_res_i = {
-						1.0f / (float)cx,
-						1.0f / (float)cy};
+					struct vec2 base_res_i;
+					base_res_i.x = 1.0f / (float)cx;
+					base_res_i.y = 1.0f / (float)cy;
 
 					gs_effect_set_vec2(scale_i_param,
 							   &base_res_i);
@@ -1500,6 +1585,17 @@ bool is_number_match(const char c)
 	return false;
 }
 
+bool match_item3(obs_scene_t *obs_scene, obs_sceneitem_t *sceneitem, void *p)
+{
+	UNUSED_PARAMETER(obs_scene);
+	struct match_item3 *mi3 = p;
+	if (obs_sceneitem_get_source(sceneitem) == mi3->check_source) {
+		mi3->matched = true;
+		return false;
+	}
+	return true;
+}
+
 struct move_item *match_item2(struct move_info *move,
 			      obs_sceneitem_t *scene_item, bool part_match,
 			      size_t *found_pos)
@@ -1519,16 +1615,6 @@ struct move_item *match_item2(struct move_info *move,
 		struct move_item *check_item = move->items_a.array[i];
 		if (check_item->item_b)
 			continue;
-		if (obs_sceneitem_get_bounds_type(check_item->item_a) ==
-			    OBS_BOUNDS_NONE &&
-		    obs_sceneitem_get_bounds_type(scene_item) !=
-			    OBS_BOUNDS_NONE)
-			continue;
-		if (obs_sceneitem_get_bounds_type(check_item->item_a) !=
-			    OBS_BOUNDS_NONE &&
-		    obs_sceneitem_get_bounds_type(scene_item) ==
-			    OBS_BOUNDS_NONE)
-			continue;
 
 		obs_source_t *check_source =
 			obs_sceneitem_get_source(check_item->item_a);
@@ -1569,6 +1655,52 @@ struct move_item *match_item2(struct move_info *move,
 				size_t len_b = strlen(name_b);
 				if (!len_a || !len_b)
 					continue;
+				const char *id_a =
+					obs_source_get_unversioned_id(
+						check_source);
+				const char *id_b =
+					obs_source_get_unversioned_id(source);
+				const char *clone_a = NULL;
+				const char *clone_b = NULL;
+				if (strcmp(id_a, "source-clone") == 0) {
+					obs_data_t *s = obs_source_get_settings(
+						check_source);
+					clone_a =
+						obs_data_get_string(s, "clone");
+					obs_data_release(s);
+				} else if (strcmp(id_a,
+						  "streamfx-source-mirror") ==
+					   0) {
+					obs_data_t *s = obs_source_get_settings(
+						check_source);
+					clone_a = obs_data_get_string(
+						s, "Source.Mirror.Source");
+					obs_data_release(s);
+				}
+
+				if (strcmp(id_b, "source-clone") == 0) {
+					obs_data_t *s =
+						obs_source_get_settings(source);
+					clone_b =
+						obs_data_get_string(s, "clone");
+					obs_data_release(s);
+				} else if (strcmp(id_b,
+						  "streamfx-source-mirror") ==
+					   0) {
+					obs_data_t *s = obs_source_get_settings(
+						check_source);
+					clone_b = obs_data_get_string(
+						s, "Source.Mirror.Source");
+					obs_data_release(s);
+				}
+				if ((clone_a && clone_b &&
+				     strcmp(clone_a, clone_b) == 0) ||
+				    (clone_a && strcmp(clone_a, name_b) == 0) ||
+				    (clone_b && strcmp(clone_b, name_a) == 0)) {
+					item = check_item;
+					*found_pos = i;
+					break;
+				}
 				if (len_a > len_b) {
 					if (move->last_word_match) {
 						char *last_space =
@@ -1667,6 +1799,63 @@ struct move_item *match_item2(struct move_info *move,
 				obs_data_release(settings);
 			}
 		}
+		if (part_match && !check_item->move_scene &&
+		    move->nested_scenes) {
+			if (obs_source_is_scene(source)) {
+				obs_scene_t *scene =
+					obs_scene_from_source(source);
+				struct match_item3 mi3;
+				mi3.check_source = check_source;
+				mi3.matched = false;
+				obs_scene_enum_items(scene, match_item3, &mi3);
+				if (mi3.matched) {
+					item = check_item;
+					item->move_scene = true;
+					*found_pos = i;
+					break;
+				}
+			} else if (obs_source_is_group(source)) {
+				obs_scene_t *scene =
+					obs_group_from_source(source);
+				struct match_item3 mi3;
+				mi3.check_source = check_source;
+				mi3.matched = false;
+				obs_scene_enum_items(scene, match_item3, &mi3);
+				if (mi3.matched) {
+					item = check_item;
+					item->move_scene = true;
+					*found_pos = i;
+					break;
+				}
+			}
+			if (obs_source_is_scene(check_source)) {
+				obs_scene_t *scene =
+					obs_scene_from_source(check_source);
+				struct match_item3 mi3;
+				mi3.check_source = source;
+				mi3.matched = false;
+				obs_scene_enum_items(scene, match_item3, &mi3);
+				if (mi3.matched) {
+					item = check_item;
+					item->move_scene = true;
+					*found_pos = i;
+					break;
+				}
+			} else if (obs_source_is_group(check_source)) {
+				obs_scene_t *scene =
+					obs_group_from_source(check_source);
+				struct match_item3 mi3;
+				mi3.check_source = source;
+				mi3.matched = false;
+				obs_scene_enum_items(scene, match_item3, &mi3);
+				if (mi3.matched) {
+					item = check_item;
+					item->move_scene = true;
+					*found_pos = i;
+					break;
+				}
+			}
+		}
 	}
 	return item;
 }
@@ -1704,26 +1893,31 @@ bool match_item(obs_scene_t *scene, obs_sceneitem_t *scene_item, void *data)
 	}
 	struct move_info *move = data;
 	size_t old_pos;
-	struct move_item *item = match_item2(move, scene_item, false, &old_pos);
-	if (!item &&
-	    (move->part_match || move->number_match || move->last_word_match)) {
-		item = match_item2(move, scene_item, true, &old_pos);
-	}
-	if (item) {
-		move->matched_items++;
-		if (old_pos >= move->item_pos)
-			move->item_pos = old_pos + 1;
-	} else {
+	struct move_item *item;
+	if (obs_sceneitem_get_source(scene_item) == move->scene_source_a) {
 		item = create_move_item();
 		da_insert(move->items_a, move->item_pos, &item);
 		move->item_pos++;
+		item->move_scene = true;
+		move->matched_scene_a = true;
+	} else {
+		item = match_item2(move, scene_item, false, &old_pos);
+		if (!item) {
+			item = match_item2(move, scene_item, true, &old_pos);
+		}
+		if (item) {
+			move->matched_items++;
+			if (old_pos >= move->item_pos)
+				move->item_pos = old_pos + 1;
+		} else {
+			item = create_move_item();
+			da_insert(move->items_a, move->item_pos, &item);
+			move->item_pos++;
+		}
 	}
 	obs_sceneitem_addref(scene_item);
 	item->item_b = scene_item;
-	item->move_scene = obs_sceneitem_get_source(scene_item) ==
-			   move->scene_source_a;
-	if (item->move_scene)
-		move->matched_scene_a = true;
+
 	da_push_back(move->items_b, &item);
 	return true;
 }
@@ -1732,16 +1926,22 @@ void sceneitem_start_move(obs_sceneitem_t *item, const char *start_move)
 {
 	obs_scene_t *scene = obs_sceneitem_get_scene(item);
 	obs_source_t *scene_source = obs_scene_get_source(scene);
+	if (obs_source_removed(scene_source))
+		return;
 	obs_source_t *filter =
 		obs_source_get_filter_by_name(scene_source, start_move);
 	if (!filter) {
 		obs_source_t *source = obs_sceneitem_get_source(item);
+		if (obs_source_removed(source))
+			return;
 		filter = obs_source_get_filter_by_name(source, start_move);
 	}
 	if (!filter)
 		return;
-	
-	if(is_move_filter(obs_source_get_unversioned_id(filter)))
+	if (obs_source_removed(filter))
+		return;
+
+	if (is_move_filter(obs_source_get_unversioned_id(filter)))
 		move_filter_start(obs_obj_get_data(filter));
 }
 
@@ -1772,6 +1972,8 @@ static void move_video_render(void *data, gs_effect_t *effect)
 		move->item_pos = 0;
 		obs_scene_t *scene_a =
 			obs_scene_from_source(move->scene_source_a);
+		if (!scene_a)
+			scene_a = obs_group_from_source(move->scene_source_a);
 		if (scene_a) {
 			obs_scene_enum_items(scene_a, add_item, data);
 		} else if (move->scene_source_a) {
@@ -1789,6 +1991,8 @@ static void move_video_render(void *data, gs_effect_t *effect)
 		move->item_pos = 0;
 		obs_scene_t *scene_b =
 			obs_scene_from_source(move->scene_source_b);
+		if (!scene_b)
+			scene_b = obs_group_from_source(move->scene_source_b);
 		if (scene_b) {
 			obs_scene_enum_items(scene_b, match_item, data);
 		} else if (move->scene_source_b) {
@@ -1799,8 +2003,7 @@ static void move_video_render(void *data, gs_effect_t *effect)
 			size_t old_pos;
 			struct move_item *item =
 				match_item2(move, scene_item, false, &old_pos);
-			if (!item && (move->part_match || move->number_match ||
-				      move->last_word_match)) {
+			if (!item) {
 				item = match_item2(move, scene_item, true,
 						   &old_pos);
 			}
@@ -2351,10 +2554,6 @@ void prop_list_add_transitions(obs_property_t *p)
 				     "None");
 	obs_frontend_get_transitions(&transitions);
 	for (size_t i = 0; i < transitions.sources.num; i++) {
-		const char *id = obs_source_get_unversioned_id(
-			transitions.sources.array[i]);
-		if (!id || strcmp(id, "move_transition") == 0)
-			continue;
 		const char *name =
 			obs_source_get_name(transitions.sources.array[i]);
 		obs_property_list_add_string(p, name, name);
@@ -2389,6 +2588,8 @@ static obs_properties_t *move_properties(void *data)
 
 	group = obs_properties_create();
 
+	obs_properties_add_bool(group, S_NESTED_SCENES,
+				obs_module_text("NestedScenes"));
 	obs_properties_add_bool(group, S_CACHE_TRANSITIONS,
 				obs_module_text("CacheTransitions"));
 
@@ -2492,7 +2693,8 @@ static obs_properties_t *move_properties(void *data)
 
 	obs_properties_add_group(ppts, S_MOVE_OUT, obs_module_text("MoveOut"),
 				 OBS_GROUP_NORMAL, group);
-
+	obs_properties_add_text(ppts, "plugin_info", PLUGIN_INFO,
+				OBS_TEXT_INFO);
 	UNUSED_PARAMETER(data);
 	return ppts;
 }
@@ -2515,6 +2717,7 @@ void move_defaults(obs_data_t *settings)
 	obs_data_set_default_double(settings, S_CURVE_IN, 0.0);
 	obs_data_set_default_double(settings, S_CURVE_OUT, 0.0);
 	obs_data_set_default_int(settings, S_SWITCH_PERCENTAGE, 50);
+	obs_data_set_default_bool(settings, S_NESTED_SCENES, true);
 }
 
 static void move_start(void *data)
@@ -2529,18 +2732,20 @@ static void move_stop(void *data)
 	clear_items(move, false);
 }
 
-struct obs_source_info move_transition = {.id = "move_transition",
-					  .type = OBS_SOURCE_TYPE_TRANSITION,
-					  .get_name = move_get_name,
-					  .create = move_create,
-					  .destroy = move_destroy,
-					  .update = move_update,
-					  .video_render = move_video_render,
-					  .audio_render = move_audio_render,
-					  .get_properties = move_properties,
-					  .get_defaults = move_defaults,
-					  .transition_start = move_start,
-					  .transition_stop = move_stop};
+struct obs_source_info move_transition = {
+	.id = "move_transition",
+	.type = OBS_SOURCE_TYPE_TRANSITION,
+	.get_name = move_get_name,
+	.create = move_create,
+	.destroy = move_destroy,
+	.update = move_update,
+	.video_render = move_video_render,
+	.audio_render = move_audio_render,
+	.get_properties = move_properties,
+	.get_defaults = move_defaults,
+	.transition_start = move_start,
+	.transition_stop = move_stop,
+};
 
 OBS_DECLARE_MODULE()
 OBS_MODULE_AUTHOR("Exeldro");
